@@ -140,7 +140,7 @@ class loggerHandlerTypes(EnumParent):
   ServerHandled = auto()
 
 class loggerInterface():
-  def __init__(self, /, logOutput=logging.getLogger(__name__), *,):
+  def __init__(self, /, logOutput=logging.getLogger(__name__)):
     self.logOutput = logOutput
 
   def pushLog(log):
